"""
Description:

    Helpers for deepnog tests.

    Including:
        - test data
        - test network weights (parameters)
        - some helper functions

    Individual tests are located within the respective deepnog subpackages.
"""
from ..utils.imports import try_import_pytorch
try_import_pytorch()
